==> serverless-builder-1.4.0.tar.gz: serverless-builder-1.4.0/serverless/aws/iam/dynamodb.py <==
from troposphere import Join
from troposphere.dynamodb import Table

from serverless.aws.iam import IAMPreset


class DynamoDBReader(IAMPreset):
    resource: Table

    def apply(self, service, sid=None):
        if not sid:
            sid = self.resource.name + "Reader"
        service.provider.iam.allow(
            sid,
            [
                "dynamodb:GetItem",
                "dynamodb:Query",
                "dynamodb:Scan",
            ],
            [
                self.resource.get_att("Arn").to_dict(),
                Join(delimiter="", values=[self.resource.get_att("Arn").to_dict(), "/index/*"]).to_dict(),
            ],
        )


class DynamoDBWriter(IAMPreset):
    def apply(self, service, sid=None):
        if not sid:
            sid = self.resource.name + "Writer"
        service.provider.iam.allow(
            sid,
            [
                "dynamodb:BatchWriteItem",
                "dynamodb:DeleteItem",
                "dynamodb:UpdateItem",
                "dynamodb:PutItem",
            ],
            [self.resource.get_att("Arn").to_dict()],
        )


class DynamoDBFulAccess(IAMPreset):
    def apply(self, service, sid=None):
        if not sid:
            sid = self.resource.name + "FullAccess"
        service.provider.iam.allow(
            sid,
            [
                "dynamodb:GetItem",
                "dynamodb:Query",
                "dynamodb:Scan",
                "dynamodb:BatchWriteItem",
                "dynamodb:DeleteItem",
                "dynamodb:UpdateItem",
                "dynamodb:PutItem",
            ],
            [self.resource.get_att("Arn").to_dict()],
        )

==> serverless-builder-1.5.1.tar.gz: serverless-builder-1.5.1/serverless/aws/iam/dynamodb.py <==
from troposphere import Join
from troposphere.dynamodb import Table

from serverless.aws.iam import IAMPreset


class DynamoDBReader(IAMPreset):
    resource: Table

    def apply(self, service, sid=None):
        if not sid:
            sid = self.resource.name + "Reader"
        service.provider.iam.allow(
            sid,
            [
                "dynamodb:GetItem",
                "dynamodb:Query",
                "dynamodb:Scan",
            ],
            [
                self.resource.get_att("Arn").to_dict(),
                Join(delimiter="", values=[self.resource.get_att("Arn").to_dict(), "/index/*"]).to_dict(),
            ],
        )


class DynamoDBWriter(IAMPreset):
    def apply(self, service, sid=None):
        if not sid:
            sid = self.resource.name + "Writer"
        service.provider.iam.allow(
            sid,
            [
                "dynamodb:BatchWriteItem",
                "dynamodb:DeleteItem",
                "dynamodb:UpdateItem",
                "dynamodb:PutItem",
            ],
            [self.resource.get_att("Arn").to_dict()],
        )


class DynamoDBFullAccess(IAMPreset):
    def apply(self, service, sid=None):
        if not sid:
            sid = self.resource.name + "FullAccess"
        service.provider.iam.allow(
            sid,
            [
                "dynamodb:GetItem",
                "dynamodb:Query",
                "dynamodb:Scan",
                "dynamodb:BatchWriteItem",
                "dynamodb:DeleteItem",
                "dynamodb:UpdateItem",
                "dynamodb:PutItem",
            ],
            [self.resource.get_att("Arn").to_dict()],
        )
